Pings the ACLED API token endpoint for authentication using email and password.
See also
ACLED API Access guide https://acleddata.com/api-documentation/getting-started
Other API and Access:
acled_api(),
acled_deletions_api(),
acled_update()
Pings the ACLED API token endpoint for authentication using email and password.
ACLED API Access guide https://acleddata.com/api-documentation/getting-started
Other API and Access:
acled_api(),
acled_deletions_api(),
acled_update()